@@ -23,6 +23,9 @@ from .widgets import (
     ReverseBar,
     BouncingBar,
     RotatingMarker,
+    VariableMixin,
+    MultiRangeBar,
+    MultiProgressBar,
     Variable,
     DynamicMessage,
     FormatCustomText,
@@ -66,6 +69,9 @@ __all__ = [
     'ProgressBar',
     'DataTransferBar',
     'RotatingMarker',
+    'VariableMixin',
+    'MultiRangeBar',
+    'MultiProgressBar',
     'Variable',
     'DynamicMessage',
     'FormatCustomText',
